@@ -84,7 +84,8 @@ extract.gt <- function(x, element="GT",
   }
   
   # Validate that the gt slot is a matrix
-  if( class(x@gt) != "matrix" ){
+#  if( class(x@gt) != "matrix" ){
+  if( !inherits(x@gt, "matrix") ){
     stop( paste("gt slot expected to be of class matrix. Instead found class", class(x@gt)) )
   }
 
@@ -181,7 +182,7 @@ extract.haps <- function(x,
     # No variants, return empty matrix.
     haps <- x@gt[ 0, -1 ]
   } else if ( ploidy == 1 ){
-    haps <- extract.gt( x )
+    haps <- extract.gt( x, return.alleles = TRUE )
   } else if ( ploidy > 1 ) {
     gt <- extract.gt( x )
     haps <- .extract_haps(x@fix[,'REF'], x@fix[,'ALT'],
@@ -194,6 +195,55 @@ extract.haps <- function(x,
 }
 
 
+#' @rdname extract_gt
+#' 
+#' @aliases is.indel
+#' 
+#' 
+#' @details 
+#' The function \strong{is.indel} returns a logical vector indicating which variants are indels (variants where an allele is greater than one character).
+#' 
+#' 
+#' @examples
+#' data(vcfR_test)
+#' is.indel(vcfR_test)
+#' 
+#' 
+#' @export
+is.indel <- function(x){
+  if(class(x) == 'chromR'){
+    x <- x@vcf
+  }
+  if(class(x) != "vcfR"){
+    stop("Unexpected class! Expecting an object of class vcfR or chromR.")
+  }
+  
+  # Create an evaluation matrix
+  isIndel <- matrix(FALSE, nrow=nrow(x), ncol = 2)
+  colnames(isIndel) <- c('REF','ALT')
+
+  # Check reference for indels
+  isIndel[,'REF'] <- nchar(x@fix[,'REF']) > 1
+
+  # Check alternate for indels
+  checkALT <- function(x){
+    x <- stats::na.omit(x)
+    x <- x[ x != "<NON_REF>" ]
+    if( length(x) > 0 ){
+      max(nchar(x)) > 1 
+    } else {
+      FALSE
+    }
+  }
+  isIndel[,'ALT'] <- unlist( lapply( strsplit(x@fix[,'ALT'], split=","), checkALT) )
+
+  mask <- rowSums(isIndel)
+  mask <- mask > 0
+
+  return(mask)
+}
+
+
 
 
 #' @rdname extract_gt
@@ -237,33 +287,7 @@ extract.indels <- function(x, return.indels=FALSE){
     stop("Unexpected class! Expecting an object of class vcfR or chromR.")
   }
   
-  # Create an evaluation matrix
-  isIndel <- matrix(FALSE, nrow=nrow(x), ncol = 2)
-  colnames(isIndel) <- c('REF','ALT')
-
-  # Check reference for indels
-  isIndel[,'REF'] <- nchar(x@fix[,'REF']) > 1
-  # Check reference for missing data.
-#  mask[ grep(".", x@fix[,'REF'], fixed = TRUE) ] <- TRUE
-  
-  # Check alternate for indels
-  checkALT <- function(x){
-    x <- stats::na.omit(x)
-    x <- x[ x != "<NON_REF>" ]
-    if( length(x) > 0 ){
-      max(nchar(x)) > 1 
-    } else {
-      FALSE
-    }
-  }
-  isIndel[,'ALT'] <- unlist( lapply( strsplit(x@fix[,'ALT'], split=","), checkALT) )
-
-  mask <- rowSums(isIndel)
-  mask <- mask > 0
-  
-  # GATK's g.vcf includes "<NON_REF>"
-#  isIndel <- x@fix[,'ALT'] == "<NON_REF>"
-  
+  mask <- is.indel(x)
 
   if(return.indels == FALSE){
     x <- x[ !mask, , drop = FALSE ]
@@ -323,4 +347,4 @@ extract.info <- function(x, element, as.numeric=FALSE, mask=FALSE){
 
 
 ##### ##### ##### ##### #####
-# EOF.
\ No newline at end of file
+# EOF.
